pymldb
======

Python interface to the [Datacratic Machine Learning Database (MLDB)](http://mldb.ai).

This library provides an `Resource` utility class, a DataFrame workalike called the `BatFrame` and some Jupyter cell magics to make it fun and easy to work with MLDB from a Notebook.

[More documentation available on mldb.ai](http://mldb.ai/doc/#builtin/Notebooks.md.html).

## Installation

`pip install pymldb`
